pub fn change_tofrunconfig(cfg: &TofRunConfig) -> Option<TofCommand>Expand description
Change the data publisher config part of the config file
pub fn change_tofrunconfig(cfg: &TofRunConfig) -> Option<TofCommand>Change the data publisher config part of the config file