pub fn change_triggerconfig(cfg: &TriggerConfig) -> Option<TofCommand>Expand description
Change the MTBSettings in the config file with relevant trigger settings
pub fn change_triggerconfig(cfg: &TriggerConfig) -> Option<TofCommand>Change the MTBSettings in the config file with relevant trigger settings