pub fn restore_default_config() -> Option<TofCommand>Expand description
Trigger the start of a new data run with the next active config
pub fn restore_default_config() -> Option<TofCommand>Trigger the start of a new data run with the next active config